#ifndef PluginHeaderH
#define PluginHeaderH

/* return values */
#define RE_SUCCESS               1
#define RE_IMPORT_COMPLETED      2
#define RE_ERROR                 3
#define RE_USER_CANCELED         4

/* plugin capabilities */
#define PC_NO_CAPS               0

/* import capabilities */
#define PI_IMPORT_UTF8           1
#define PI_IMPORT_ANSI           2

/* export capabilities */
#define PE_EXPORT_UTF8           1

/* text data types */
#define TD_TEXT                  0
#define TD_RTF                   1
#define TD_RVF                   2

/* Sensitivity values */
#define SE_NORMAL                0
#define SE_PERSONAL              1
#define SE_PRIVATE               2
#define SE_CONFIDENTIAL          3

/* Priority values */
#define PT_LOW                   0
#define PT_NORMAL                1
#define PT_HIGH                  2

/* Custom column types */
#define CT_TEXT                  0
#define CT_NUMBER                1
#define CT_CURRENCY              2
#define CT_YES_NO                3
#define CT_POPUP_LIST            4
#define CT_CATEGORY              5
#define CT_DATE_TIME             6

/* CT_NUMBER formats */
#define NF_INTEGER               0
#define NF_FRACTIONAL            1

/* CT_YES_NO formats */
#define YF_YES_NO                0
#define YF_TRUE_FALSE            1
#define YF_ON_OFF                2
#define YF_ICON                  3

/* Custom column alignments */
#define CA_LEFT_AL                 0
#define CA_RIGHT_AL                1
#define CA_CENTER_AL               2

/* Memory request options */
#define MR_TEXT_DATA             1
#define MR_EMBEDDED_FILE_DATA    2

/* Memory request return values */
#define MV_ERROR                 0
#define MV_SUCCESS               1

typedef struct
    {
    char Version[256];
    char PluginName[256];
    char Description[1001];
    char Author[256];
    char Copyright[256];
    int ImportCaps;
    int ExportCaps;
    int ImportTextFormat;
    int ExportTextFormat;
    char FileExt[51];
    char FileExtDescription[256];
    } TPluginInfo;

typedef struct
    {
    char Caption[256];
    int ColType;
    int Format;
    char Values[5001];
    int Alignment;
    int Width;
    int Visible;
    } TCustomColumn;

typedef struct
    {
    int Level;
    char Title[256];
    int Sensitivity;
    int Priority;
    char Comment[1025];
    char Tags[1025];
    char Link[256];
    char ColumnValues[10001];
    int StateIcon;
    char DateCreated[20];
    char DateModified[20];
    char DateStarted[20];
    char DateDue[20];
    char DateCompleted[20];
    char DateReminder[20];
    int PercentCompleted;
    int Id; // ignored on import

    char* TextData;
    int TextDataSize;

    char EmbeddedFileName[256];
    char* EmbeddedFileData;
    int EmbeddedFileDataSize;
    } TDocument;

typedef int (__stdcall *TMemoryRequestProc)(TDocument* document, int targetMemory, int newMemorySize);

#endif

