library TebIntendedD;

{
 This is simple Delphi-written plugin, which shows the basics of working with
 MyInfo Open Plugins architecture. Use it as skeleton to build your own plugins

 NOTE: Lines should be up to 255 characters long
}

{ Important note about DLL memory management: ShareMem must be the
  first unit in your library's USES clause AND your project's (select
  Project-View Source) USES clause if your DLL exports any procedures or
  functions that pass strings as parameters or function results. This
  applies to all strings passed to and from your DLL--even those that
  are nested in records and classes. ShareMem is the interface unit to
  the BORLNDMM.DLL shared memory manager, which must be deployed along
  with your DLL. To avoid using BORLNDMM.DLL, pass string information
  using PChar or ShortString parameters. }

uses
    SysUtils,
    Classes,
    StrUtils,
    PluginUnit in '..\..\Header Files\PluginUnit.pas';

var
    importFile : TextFile;
    exportFile : TextFile;

{$R *.res}

function GetPluginInfo(info : PPluginInfo) : integer; stdcall;
begin
    StrCopy(info.Version, '1.0');
    StrCopy(info.PluginName, 'Tab-intended files (Delphi Sample)');
    StrCopy(info.Description, 'Sample plugin written in Borland Delphi, which imports from and exports to tab-intended text files');
    StrCopy(info.Author, 'Milenix Software Ltd.');
    StrCopy(info.Copyright, 'Copyright (c) 2007 Milenix Software Ltd.');
    info.ImportCaps := PI_IMPORT_UTF8;
    info.ExportCaps := PE_EXPORT_UTF8;
    info.ImportTextFormat := TD_TEXT;
    info.ExportTextFormat := TD_TEXT;
    StrCopy(info.FileExt, '.txt');
    StrCopy(info.FileExtDescription, 'Tab-intended text files (*.txt)');
    
    result := RE_SUCCESS;
end;

{ Import section }

function BeginImportSession(fileName : pchar; callerWindow : THandle; dllInstance : longword) : integer; stdcall;
begin
    { open import file }
    AssignFile(importFile, fileName);
    Reset(importFile);
    result := RE_SUCCESS;
end;

function ImportDocument(document: PDocument; memoryRequestProc : TMemoryRequestProc) : integer; stdcall;
var
    line : string;
    level,
    i : integer;
begin
    { if end-of-file is reached, import process is completed }
    if Eof(importFile) then result := RE_IMPORT_COMPLETED
    else
    { if more lines are in the file, process them }
    begin
        { read first non-blank line }
        repeat
            ReadLn(importFile, line);
        until line <> '';

        { determine document levels based on the tabs in the beginning of the line }
        level := 0;
        i := 1;
        while line[i] = Char(9) do
        begin
            Inc(i);
            Inc(level);
        end;

        { trim tab characters from the line beginning }
        Delete(line, 1, level);

        { assign document properties }
        document.Level := level;
        StrCopy(document.Title, pchar(line));

        result := RE_SUCCESS;
    end;
end;

function EndImportSession() : integer; stdcall;
begin
    CloseFile(importFile);

    result := RE_SUCCESS;
end;

{ Export Section }
function BeginExportSession(fileName : pchar; callerWindow : THandle; dllInstance : longword) : integer; stdcall;
begin
    AssignFile(exportFile, fileName);
    Rewrite(exportFile);
    result := RE_SUCCESS;
end;

function ExportDocument(document: PDocument) : integer; stdcall;
var
    line : pchar;
begin
    GetMem(line, document.Level + StrLen(document.Title) + 1 + 20);
    { create string beginning with number of tabs equal to the document level }
    StrCopy(line, PChar(DupeString(Char(9), document.Level)));
    StrCat(line, document.Title);
    StrCat(line, PChar(IntToStr(document.TextDataSize)));
    { write line to export file }
    WriteLn(exportFile, line);
    Freemem(line);

    result := RE_SUCCESS;
end;

function EndExportSession() : integer; stdcall;
begin
    CloseFile(exportFile);

    result := RE_SUCCESS;
end;


{ Export DLL functions }
exports
    GetPluginInfo,
    BeginImportSession,
    ImportDocument,
    EndImportSession,
    BeginExportSession,
    ExportDocument,
    EndExportSession;

begin
end.
